<?php

/**
 * @file
 * Code for customizing menus and menu blocks markup.
 */

/**
 * Implements THEME_block_view_alter().
 */
function diba_core_block_view_alter(&$build, &$block) {
  $special_regions = array(
    'menu',
    'menu2',
  );
  if (!in_array($block->region, $special_regions)) {
    return;
  }
  if (empty($build['content']) || !is_array($build['content'])) {
    return;
  }

  // Support menu_block blocks.
  if (!empty($build['content']['#content']['#theme_wrappers'][0][0])) {
    if (strpos($build['content']['#content']['#theme_wrappers'][0][0], 'menu_tree__') !== FALSE) {
      $block->title = '<none>';
      _diba_core_mark_menu_items($build['content']['#content'], $block->region);
    }
  }
  // Support core menu blocks.
  elseif (!empty($build['content']['#theme_wrappers'][0])) {
    if (strpos($build['content']['#theme_wrappers'][0], 'menu_tree__') !== FALSE) {
      $block->title = '<none>';
      _diba_core_mark_menu_items($build['content'], $block->region);
    }
  }
}

/**
 * Recursively mark menu links as being in a certain region.
 */
function _diba_core_mark_menu_items(&$element, $region) {
  foreach (element_children($element) as $key) {
    // Drop a note in all the menu links for later use in diba_core_menu_link().
    $element[$key]['#diba_core_menu_region'] = $region;
    // Recursively if there are children.
    if (!empty($element[$key]['#below'])) {
      _diba_core_mark_menu_items($element[$key]['#below'], $region);
    }
  }
}

/**
 * Implements THEME_preprocess_menu_tree().
 */
function diba_core_preprocess_menu_tree(&$variables) {
  $variables['#attributes'] = array();
  $variables['#attributes']['class'][] = 'nav';

  // See special flag on the menu items.
  $menu_region = FALSE;
  foreach (element_children($variables['#tree']) as $key) {
    if (!empty($variables['#tree'][$key]['#diba_core_menu_region'])) {
      $menu_region = $variables['#tree'][$key]['#diba_core_menu_region'];
    }
    // We only need to see one.
    break;
  }

  // Special menu customization.
  if ($menu_region) {
    if ($menu_region == 'menu2') {
      $nav_class = 'navbar-inverse';
      $variables['#attributes']['class'][] = 'navbar-nav';
    }
    else {
      $nav_class = 'navbar-default';
      $variables['#attributes']['class'][] = 'nav-justified';
    }
    $collapse_class = 'js-navbar-collapse-' . $menu_region;
    $variables['#prefix'] = '<nav class="navbar ' . $nav_class . ' dibamenu">
    <div class="container-fluid">
      <div class="navbar-header">
        <button class="navbar-toggle" type="button" data-toggle="collapse" data-target=".' . $collapse_class . '">
          <span class="sr-only">' . t('Toggle menu') . '</span>
          <span class="icon-bar"></span>
          <span class="icon-bar"></span>
          <span class="icon-bar"></span>
        </button>
      </div>
      <div class="navbar-collapse collapse ' . $collapse_class . ' menu-elements">';
    $variables['#suffix'] = '</div></div></nav>';
    $variables['#attributes']['class'][] = 'menu';
  }
}

/**
 * Implements THEME_menu_tree().
 */
function diba_core_menu_tree($variables) {
  $prefix = isset($variables['#prefix']) ? $variables['#prefix'] : '';
  $suffix = isset($variables['#suffix']) ? $variables['#suffix'] : '';

  // Menu heading for accesibility.
  $output = '<h2 class="sr-only">' . t('Menu') . '</h2>';
  // Drupal's default theme_menu_tree() hardcodes the class attribute. Override
  // and use our dynamic class attribute instead.
  $output .= '<ul ' . drupal_attributes($variables['#attributes']) . '>' . $variables['tree'] . '</ul>';

  return $prefix . $output . $suffix;
}

/**
 * Implements THEME_menu_link().
 */
function diba_core_menu_link(array $variables) {
  $element = $variables['element'];

  // Merge with localized options.
  $options = !empty($element['#localized_options']) ? $element['#localized_options'] : array();

  $title = _diba_core_get_secured_title($element);
  // This is secure because we are secured title and user menu inputs.
  $options['html'] = TRUE;

  $menu_attributes = !empty($element['#attributes']) ? $element['#attributes'] : array();

  $dropdown = '';
  if ($element['#below']) {
    // Prevent dropdown functions from being added to management menu so it
    // does not affect the navbar module.
    if (($element['#original_link']['menu_name'] == 'management') && (module_exists('navbar'))) {
      $dropdown = drupal_render($element['#below']);
    }
    elseif (!empty($element['#original_link']['depth']) && $element['#original_link']['depth'] == 1) {
      // Generate our custom dropdown and wrapper.
      unset($element['#below']['#theme_wrappers']);

      // To determine which menu we're dealing with, we look for a certain flag.
      $menu_region = (isset($element['#diba_core_menu_region']) && !empty($element['#diba_core_menu_region'])) ? $element['#diba_core_menu_region'] : FALSE;

      if ($menu_region) {
        // We are in a special menu region.
        $dropdown_class = ($menu_region == 'menu2') ? 'inverse-dropdown ' : '';
        $dropdown_class .= 'dropdown-menu submenu-' . $element['#original_link']['mlid'];

        if (!empty($options['attributes']['title'])) {
          // With description render as full media menu.
          $menu_attributes['class'][] = 'dibamenu-fw';

          // Open submenu row.
          $dropdown = '<ul class="' . $dropdown_class . '"><li>';

          // Render menu description.
          $dropdown .= '<div class="col-sm-4"><div class="media dibamenu-content"><div class="media-body">';

          $heading_options = array(
            'attributes' => array('class' => array('media-title')),
            'html' => TRUE,
          );
          $dropdown .= '<h4 class="media-heading">' . l($title, $element['#href'], $heading_options) . '</h4>';

          $dropdown .= $options['attributes']['title'];
          $dropdown .= '</div></div></div>';

          // Render child menu links.
          $dropdown .= '<div class="col-sm-8">';
          $ul_attributes = array('class' => 'list-dibamenu row');
          $li_attributes = array('class' => 'col-sm-6');
          $dropdown .= _diba_core_submenu_list($element['#below'], $ul_attributes, $li_attributes);
          $dropdown .= '</div>';

          // Close submenu row.
          $dropdown .= '</li></ul>';
        }
        else {
          // Without description render submenu as estandard dropdown.
          $ul_attributes = array('class' => $dropdown_class);
          $li_attributes = array();
          $dropdown = _diba_core_submenu_list($element['#below'], $ul_attributes, $li_attributes);
        }

        // data-link attribute for js/menu-dbclick javascript functionality.
        $options['attributes']['data-link'][] = url($element['#href']);
      }
      else {
        // Default dropdown bootstrap markup.
        $dropdown = '<ul class="dropdown-menu">' . drupal_render($element['#below']) . '</ul>';
      }

      // Generate as standard bottsrap dropdown main menu.
      $title .= ' <span class="caret"></span>';
      $menu_attributes['class'][] = 'dropdown';

      // Set dropdown trigger element to # to prevent inadvertent page loading
      // when a submenu link is clicked.
      $options['attributes']['data-target'] = '#';
      $options['attributes']['class'][] = 'dropdown-toggle';
      $options['attributes']['data-toggle'] = 'dropdown';
    }
  }

  return '<li' . drupal_attributes($menu_attributes) . '>' . l($title, $element['#href'], $options) . $dropdown . "</li>\n";
}

/**
 * Returns submenu HTML list.
 */
function _diba_core_submenu_list(array $element, $ul_attributes, $li_attributes) {
  $list = '<ul' . drupal_attributes($ul_attributes) . '>';
  foreach ($element as $link) {
    if (is_array($link) && isset($link['#title'])) {
      $title = _diba_core_get_secured_title($link);
      $span_attributes = isset($link['#attributes']) ? drupal_attributes($link['#attributes']) : '';

      $list .= '<li' . drupal_attributes($li_attributes) . '>';
      if (isset($link['#href'])) {
        $list .= '<a href="' . check_plain(url($link['#href'], $link)) . '"' . $span_attributes . '>' . $title . '</a>';
      }
      else {
        $list .= '<span' . $span_attributes . '>' . $title . '</span>';
      }
      $list .= '</li>';
    }
  }
  $list .= '</ul>';

  return $list;
}

/**
 * Return text plain or secured HTML for HTML menu module integration.
 */
function _diba_core_get_secured_title($element) {
  return empty($element['html']) && empty($element['#localized_options']['html']) ? check_plain($element['#title']) : filter_xss_admin($element['#title']);
}
