<?php

/**
 * @file
 * Set page template vars.
 */

/**
 * Pre-processes variables for the "page" theme hook.
 *
 * @see page.tpl.php
 *
 * @ingroup theme_preprocess
 */

/**
 * Implements THEME_preprocess_page().
 */
function diba_core_preprocess_page(&$variables) {
  // Custom block search.
  $variables['search_show'] = theme_get_setting('search_show');
  if (theme_get_setting('search_show')) {
    $form = drupal_get_form('search_form');
    $search_box = drupal_render($form);
    $variables['custom_search_box'] = $search_box;
  }

  // Logos.
  $theme_path = base_path() . drupal_get_path('theme', 'diba_core');
  // Left logo.
  $variables['left_logo_top'] = $variables['left_logo_bottom'] = '';
  $variables['left_logo_show'] = theme_get_setting('left_logo_show');
  if ($variables['left_logo_show']) {
    $left_logo = theme_get_setting('left_logo');
    if ($left_logo > 0) {
      $left_logo = file_load($left_logo);
      if (!empty($left_logo)) {
        $left_logo = file_create_url($left_logo->uri);
      }
    }
    else {
      $left_logo = theme_get_setting('left_logo_url');
    }
    $left_logo = empty($left_logo) ? $theme_path . '/imgs/logo-left.jpg' : $left_logo;

    $left_logo_link = trim(theme_get_setting('left_logo_link'));
    $left_logo_link_target = ' target="_blank"';
    $left_logo_title = theme_get_setting('left_logo_title');
    if ($left_logo_link == '<front>' || empty($left_logo_link)) {
      $left_logo_link = base_path();
      $left_logo_link_target = '';
    }
    $variables['left_logo_top'] = '<a href="' . $left_logo_link . '" title="' . $left_logo_title . '"' . $left_logo_link_target . '><img src="' . $left_logo . '" height="45" alt="" class="img-responsive logo45 pull-left"></a>';
    $variables['left_logo_bottom'] = '<a href="' . $left_logo_link . '" title="' . $left_logo_title . '"' . $left_logo_link_target . '><img src="' . $left_logo . '" height="45" alt="" class="img-responsive logo45"></a>';
  }

  // Right logo.
  $variables['right_logo_top'] = $variables['right_logo_bottom'] = '';
  $variables['right_logo_show'] = theme_get_setting('right_logo_show');
  if ($variables['right_logo_show']) {
    $right_logo = theme_get_setting('right_logo');
    if ($right_logo > 0) {
      $right_logo = file_load($right_logo);
      if (!empty($right_logo)) {
        $right_logo = file_create_url($right_logo->uri);
      }
    }
    else {
      $right_logo = theme_get_setting('right_logo_url');
    }
    $right_logo = empty($right_logo) ? $theme_path . '/imgs/logo-right.jpg' : $right_logo;

    $right_logo_link = trim(theme_get_setting('right_logo_link'));
    $right_logo_link_target = ' target="_blank"';
    $right_logo_title = theme_get_setting('right_logo_title');
    if ($right_logo_link == '<front>' || empty($right_logo_link)) {
      $right_logo_link = base_path();
      $right_logo_link_target = '';
    }
    $variables['right_logo_top'] = '<a href="' . $right_logo_link . '" title="' . $right_logo_title . '"' . $right_logo_link_target . '><img src="' . $right_logo . '" height="45" alt="" class="img-responsive logo45 pull-right"></a>';
    $variables['right_logo_bottom'] = '<a href="' . $right_logo_link . '" title="' . $right_logo_title . '"' . $right_logo_link_target . '><img src="' . $right_logo . '" height="45" alt="" class="img-responsive logo45"></a>';
  }

  // Social networks.
  $variables['x_block'] = '';
  if (theme_get_setting('x_show')) {
    $xarxes = diba_core_social_networks();
    foreach ($xarxes as $xarxa) {
      $x_link = theme_get_setting('x_' . $xarxa);
      if (!empty($x_link)) {
        $img = '<img src="' . $theme_path . '/imgs/xarxes/' . $xarxa . '.png' . '" alt="" class="' . $xarxa . '">';
        $options = array(
          'html' => TRUE,
          'external' => TRUE,
          'attributes' => array('title' => ucfirst($xarxa), 'target' => '_blank'),
        );
        $variables['x_block'] .= l($img, $x_link, $options);
      }
    }
  }

  // Scaffolding classes.
  $page = $variables['page'];
  // Header scaffolding classes.
  $count_left   = !empty($page['xarxes1']) ? 1 : 0;
  $count_right  = !empty($page['sup1']) ? 1 : 0;
  $count_right += ($variables['search_show'] || !empty($page['cerca'])) ? 1 : 0;
  $count_right += !empty($page['sup2']) ? 1 : 0;

  $classes = diba_core_headers_classes($count_left, $count_right);
  $variables['class_box_right_offset'] = $classes['box_right_offset'];
  $variables['class_box_right'] = $classes['box_right'];
  $variables['class_box_left'] = $classes['box_left'];

  // Content scaffolding classes.
  $col_left = !empty($page['secundary_left']) ? TRUE : FALSE;
  $col_right = (!empty($page['secundary_right1']) || !empty($page['secundary_right2']) || !empty($page['secundary_right3'])) ? TRUE : FALSE;
  $col_right_double = (!empty($page['secundary_right2']) && !empty($page['secundary_right3'])) ? TRUE : FALSE;

  // Pre/post content classes.
  $variables['class_pre'] = !empty($page['pre_content']) && !empty($page['pre_content2']) ? 'col-sm-6' : 'col-sm-12';
  $variables['class_post'] = !empty($page['post_content']) && !empty($page['post_content2']) ? 'col-sm-6' : 'col-sm-12';

  // Content classes.
  $classes = diba_core_content_classes($col_left, $col_right, $col_right_double);
  $variables['class_content'] = $classes['content'];
  $variables['class_left'] = $classes['left'];
  $variables['class_right'] = $classes['right'];
  $variables['class_inner'] = $classes['inner'];
  $variables['class_double'] = $classes['double'];
}

/**
 * Return scaffolding header classes.
 */
function diba_core_headers_classes($count_left, $count_right) {

  $default = array(
    'box_right_offset' => '',
    'box_right' => 'col-sm-3 col-md-2',
    'box_left' => 'col-sm-3 col-md-6',
  );

  $header_classes = array();
  if ($count_left == 0 && $count_right > 0) {
    $header_classes = array(
      1 => array(
        'box_right_offset' => 'col-sm-offset-8 col-md-offset-9 ',
        'box_right' => 'col-sm-4 col-md-3',
      ),
      2 => array(
        'box_right_offset' => 'col-sm-offset-4 col-md-offset-6 ',
        'box_right' => 'col-sm-4 col-md-3',
      ),
      3 => array(
        'box_right_offset' => 'col-sm-offset-3 col-md-offset-6 ',
      ),
    );
    $header_classes = $header_classes[$count_right];
  }
  elseif ($count_left == 1 && $count_right > 0 && $count_right < 3) {
    $header_classes = array(
      1 => array(
        'box_right_offset' => 'col-sm-offset-4 col-md-offset-3 ',
        'box_right' => 'col-sm-4 col-md-3',
        'box_left' => 'col-sm-4 col-md-6',
      ),
      2 => array(
        'box_right' => 'col-sm-4 col-md-3',
        'box_left' => 'col-sm-4 col-md-6',
      ),
    );
    $header_classes = $header_classes[$count_right];
  }

  $header_classes = array_merge($default, $header_classes);

  return $header_classes;
}

/**
 * Return scaffolding content classes.
 */
function diba_core_content_classes($col_left, $col_right, $col_right_double) {

  $default = array(
    'content' => 'col-sm-6',
    'left' => 'col-sm-2',
    'right' => 'col-sm-4',
    'inner' => 'col-sm-6',
    'double' => 'col-sm-12',
  );

  $content_classes = array();
  if ($col_left && $col_right && !$col_right_double) {
    $content_classes = array(
      'left' => 'col-sm-3',
      'right' => 'col-sm-3',
      'inner' => 'col-sm-12',
    );
  }
  elseif ($col_left && !$col_right) {
    $content_classes = array(
      'content' => 'col-sm-8',
      'left' => 'col-sm-4',
    );
  }
  elseif (!$col_left && $col_right && $col_right_double) {
    $content_classes = array(
      'right' => 'col-sm-6',
    );
  }
  elseif (!$col_left && $col_right && !$col_right_double) {
    $content_classes = array(
      'content' => 'col-sm-8',
      'inner' => 'col-sm-12',
    );
  }
  elseif (!$col_left && !$col_right && !$col_right_double) {
    $content_classes = array(
      'content' => 'col-sm-12',
    );
  }

  $content_classes = array_merge($default, $content_classes);

  return $content_classes;
}
