<?php

/**
 * @file
 * Theme settings for diba_core.
 */

/**
 * Include common functions used through out theme.
 */
include_once dirname(__FILE__) . '/includes/common.inc';

/**
 * Implements template_form_system_theme_settings_alter().
 */
function diba_core_form_system_theme_settings_alter(&$form, &$form_state) {
  // Amaguem les opcions que no s'utilitzen.
  $form['theme_settings']['#access'] = FALSE;
  $form['logo']['#access'] = FALSE;
  // DiBa settings.
  $form['diba_core'] = array(
    '#type'        => 'fieldset',
    '#title'       => t('DiBa Core Settings'),
    '#collapsible' => TRUE,
    '#collapsed'   => FALSE,
    '#description' => t('Custom DiBa template configuration.'),
  );
  $form['diba_core']['google_site_verification'] = array(
    '#type'          => 'textfield',
    '#title'         => t('Google site verification code'),
    '#default_value' => theme_get_setting('google_site_verification'),
  );
  $form['diba_core']['x_show'] = array(
    '#type' => 'checkbox',
    '#title' => t('Show social networks footer icons.'),
    '#default_value' => theme_get_setting('x_show'),
  );
  $form['diba_core']['sharer_show'] = array(
    '#type' => 'checkbox',
    '#title' => t('Show share button on social networks in detail.'),
    '#default_value' => theme_get_setting('sharer_show'),
  );
  $form['diba_core']['search_show'] = array(
    '#type' => 'checkbox',
    '#title' => t('Show top search form.'),
    '#default_value' => theme_get_setting('search_show'),
  );
  $form['diba_core']['left_logo_show'] = array(
    '#type' => 'checkbox',
    '#title' => t('Show left logo.'),
    '#default_value' => theme_get_setting('left_logo_show'),
  );
  $form['diba_core']['right_logo_show'] = array(
    '#type' => 'checkbox',
    '#title' => t('Show right logo.'),
    '#default_value' => theme_get_setting('right_logo_show'),
  );

  $default_file_dir = 'public://template/logos';
  $folder = file_prepare_directory($default_file_dir, FILE_CREATE_DIRECTORY);
  $theme = $form_state['build_info']['args'][0];
  $form['diba_core']['logos_group'] = array(
    '#type'        => 'fieldset',
    '#title'       => t('Logos'),
    '#collapsible' => TRUE,
    '#collapsed'   => FALSE,
  );

  $form['diba_core']['logos_group']['left_group'] = array(
    '#type'        => 'fieldset',
    '#title'       => t('Left logo'),
    '#collapsible' => TRUE,
    '#collapsed'   => FALSE,
  );
  $left_logo = theme_get_setting('left_logo');
  if ($folder) {
    // BUG: Les imategs es guarden com a temporals.
    if (!empty($left_logo)) {
      _diba_core_fix_permanent_image('left_logo', $theme);
    }
    $form['diba_core']['logos_group']['left_group']['left_logo'] = array(
      '#type'               => 'managed_file',
      '#title'              => t('Left logo'),
      '#default_value'      => $left_logo,
      '#progress_message'   => t('Please wait...'),
      '#progress_indicator' => 'bar',
      '#upload_location'    => $default_file_dir,
      '#description'        => t('Left logo height 45px.'),
      '#upload_validators'  => array(
        'file_validate_extensions' => array('gif png jpg jpeg'),
        'file_validate_image_resolution' => array('375x45', '30x45'),
      ),
    );
  }
  if (empty($left_logo)) {
    $form['diba_core']['logos_group']['left_group']['left_logo_url'] = array(
      '#type'          => 'textfield',
      '#title'         => t('Left logo url'),
      '#default_value' => theme_get_setting('left_logo_url'),
      '#description'   => t('Use an external URL image for the logo instead of a file.'),
    );
  }
  $form['diba_core']['logos_group']['left_group']['left_logo_title'] = array(
    '#type'          => 'textfield',
    '#title'         => t('Left logo title'),
    '#default_value' => theme_get_setting('left_logo_title'),
  );
  $form['diba_core']['logos_group']['left_group']['left_logo_link'] = array(
    '#type'          => 'textfield',
    '#title'         => t('Left logo link'),
    '#default_value' => theme_get_setting('left_logo_link'),
    '#description'   => t('Left logo link, use &lt;front&gt; to link frontpage.'),
  );
  $form['diba_core']['logos_group']['left_group']['left_logo_title'] = array(
    '#type'          => 'textfield',
    '#title'         => t('Left logo title'),
    '#default_value' => theme_get_setting('left_logo_title'),
  );

  $form['diba_core']['logos_group']['right_group'] = array(
    '#type'        => 'fieldset',
    '#title'       => t('Right logo'),
    '#collapsible' => TRUE,
    '#collapsed'   => FALSE,
  );
  $right_logo = theme_get_setting('right_logo');
  if ($folder) {
    // BUG: Les imatges es guarden com a temporals.
    if (!empty($right_logo)) {
      _diba_core_fix_permanent_image('right_logo', $theme);
    }
    $form['diba_core']['logos_group']['right_group']['right_logo'] = array(
      '#type'               => 'managed_file',
      '#title'              => t('Right logo'),
      '#default_value'      => $right_logo,
      '#progress_message'   => t('Please wait...'),
      '#progress_indicator' => 'bar',
      '#upload_location'    => $default_file_dir,
      '#description'        => t('Right logo height 45px.'),
      '#upload_validators'  => array(
        'file_validate_extensions' => array('gif png jpg jpeg'),
        'file_validate_image_resolution' => array('375x45', '30x45'),
      ),
    );
  }
  if (empty($right_logo)) {
    $form['diba_core']['logos_group']['right_group']['right_logo_url'] = array(
      '#type'          => 'textfield',
      '#title'         => t('Right logo url'),
      '#default_value' => theme_get_setting('right_logo_url'),
      '#description'   => t('Use an external URL image for the logo instead of a file.'),
    );
  }
  $form['diba_core']['logos_group']['right_group']['right_logo_link'] = array(
    '#type'          => 'textfield',
    '#title'         => t('Right logo link'),
    '#default_value' => theme_get_setting('right_logo_link'),
    '#description'   => t('Right logo link, use &lt;front&gt; to link frontpage.'),
  );
  $form['diba_core']['logos_group']['right_group']['right_logo_title'] = array(
    '#type'          => 'textfield',
    '#title'         => t('Right logo title'),
    '#default_value' => theme_get_setting('right_logo_title'),
  );

  $form['diba_core']['xarxes_group'] = array(
    '#type'        => 'fieldset',
    '#title'       => t('Socials networks'),
    '#collapsible' => TRUE,
    '#collapsed'   => FALSE,
  );

  $xarxes = diba_core_social_networks();
  foreach ($xarxes as $xarxa) {
    $form['diba_core']['xarxes_group']['x_' . $xarxa] = array(
      '#type'          => 'textfield',
      '#title'         => ucfirst($xarxa),
      '#default_value' => theme_get_setting('x_' . $xarxa),
      '#description'   => t('Link to @network.', array('@network' => $xarxa)),
    );
  }
}

/**
 * Set image logos as permanent files.
 */
function _diba_core_fix_permanent_image($image, $theme) {
  $fid = theme_get_setting($image, $theme);
  if ($fid > 0) {
    $file = file_load($fid);
    if (is_object($file) && $file->status == 0) {
      $file->status = FILE_STATUS_PERMANENT;
      file_save($file);
      // Add a usage reference to prevent warnings.
      file_usage_add($file, $theme, 'theme', 1);
      drupal_set_message(t('@image saved as permanent to theme @theme.'), array('@image' => $image, '@theme' => $theme));
    }
  }
}
